package com.zopim.android.sdk.api;

import android.support.annotation.NonNull;

/**
 * Interface definition of the chat
 * <p>
 * This interface describes available communication and configuration APIs for a given chat session.
 * </p>
 */
public interface ChatApi extends ChatApiCommands {

    /**
     * Gets chat config for the current chat session as configured via {@link ZopimChatApi}
     * <p>
     * It will reflect {@link ZopimChatApi.DefaultConfig} configuration values unless overridden via {@link ZopimChatApi.SessionConfig} at chat start.
     * </p>
     *
     * @return chat configuration
     */
    @NonNull
    ChatApiConfig getConfig();

    /**
     * Tells if this chat session has ended and can not be continued.
     *
     * @return true if ended, false otherwise
     */
    boolean hasEnded();

    /**
     * Resets chat timeout.
     * This will offset the timeout by the value configured via {@link ZopimChatApi.DefaultConfig#sessionTimeout(long)}.
     */
    void resetTimeout();
}
