package com.zopim.android.sdk.api;

import android.support.annotation.NonNull;
import android.support.annotation.Nullable;
import com.zopim.android.sdk.model.VisitorInfo;

/**
 * Chat configuration interface
 * <p>
 * Used to tell what is the chat configuration of the current chat session.
 * Configuration is passed during initialization and start of the chat.
 * </p>
 *
 * @see ZopimChatApi.DefaultConfig
 * @see ZopimChatApi.SessionConfig
 */
public interface ChatApiConfig {

    /**
     * Gets department as configured at initialization via {@link ZopimChatApi.DefaultConfig} or start of the chat via {@link ZopimChatApi.SessionConfig}
     *
     * @return department as configured
     */
    @NonNull
    String getDepartment();

    /**
     * Gets tags as configured at initialization via {@link ZopimChatApi.DefaultConfig} or start of the chat via {@link ZopimChatApi.SessionConfig}
     *
     * @return tags in this chat
     */
    @NonNull
    String[] getTags();

    /**
     * Gets {@link com.zopim.android.sdk.model.VisitorInfo} configured for this chat session
     *
     * @return visitor info
     */
    @NonNull
    VisitorInfo getVisitorInfo();
}
