package com.zopim.android.sdk.api;

import java.util.concurrent.TimeUnit;

/**
 * Interface definition of the chat session
 * <p>
 * Defines set of defaults and constraints for configuring chat session timeouts.
 * </p>
 */
public interface ChatSession {

    /**
     * Defines the action for chat initialization timeout.
     * Register {@link android.content.BroadcastReceiver} to filter {@link android.content.IntentFilter#addAction(String)} intents with this action.
     */
    String ACTION_CHAT_INITIALIZATION_TIMEOUT = "chat.action.INITIALIZATION_TIMEOUT";

    /**
     * Defined the action for chat session timeout.
     * Register {@link android.content.BroadcastReceiver} to filter {@link android.content.IntentFilter#addAction(String)} intents with this action.
     */
    String ACTION_CHAT_SESSION_TIMEOUT = "chat.action.TIMEOUT";

    /**
     * Intent action notifying that the primary chat messages UI has paused.
     */
    String ACTION_CHAT_BACKGROUND = "chat.action.BACKGROUND";

    /**
     * Intent action notifying that the primary chat messages UI has resumed.
     */
    String ACTION_CHAT_FOREGROUND = "chat.action.FOREGROUND";

    /**
     * Intent action notifying that the app has moved to foreground.
     */
    String ACTION_CHAT_APP_FOREGROUND = "chat.action.app.FOREGROUND";

    /**
     * Intent action notifying that the app has moved to background.
     */
    String ACTION_CHAT_APP_BACKGROUND = "chat.action.app.BACKGROUND";

    /**
     * Defines default chat initialization timeout.
     * To specify different timeout use {@link ZopimChatApi.DefaultConfig#initializationTimeout(long)}
     */
    long DEFAULT_CHAT_INITIALIZATION_TIMEOUT = TimeUnit.SECONDS.toMillis(40);

    /**
     * Defines default reconnect timeout.
     * To specify different timeout use {@link ZopimChatApi.DefaultConfig#reconnectTimeout(long)}
     */
    long DEFAULT_RECONNECT_TIMEOUT = TimeUnit.MINUTES.toMillis(2);

    /**
     * Defines default chat session timeout.
     * To specify different timeout use {@link ZopimChatApi.DefaultConfig#initializationTimeout(long)}
     */
    long DEFAULT_CHAT_SESSION_TIMEOUT = TimeUnit.MINUTES.toMillis(5);
}
