package com.zopim.android.sdk.api;

/**
 * Representation of the chat state
 * <p>
 *     This is a simplified version of chat state from the <a href="https://dashboard.zopim.com/#visualization/state">dashboard</a>
 * </p>
 * <ul>
 *     <li>{@link ChatState#INITIALIZING}</li>
 *     <li>{@link ChatState#INITIALIZED}</li>
 *     <li>{@link ChatState#STARTED}</li>
 *     <li>{@link ChatState#DISCONNECTED}</li>
 *     <li>{@link ChatState#ENDING}</li>
 *     <li>{@link ChatState#ENDED}</li>
 * </ul>
 */
enum ChatState {

    /**
     * Web widget initialization in progress.
     * Widget is receiving account settings.
     * We have not received the initial connected state yet.
     */
    INITIALIZING,
    /**
     * Web widget is connected.
     * Account settings are retrieved.
     * Chat is now in CLICKED state in the <a href="https://dashboard.zopim.com/#visualization/state">dashboard</a>.
     */
    INITIALIZED,
    /**
     * Visitor has sent a first message.
     * Chat is now in INCOMING state in the <a href="https://dashboard.zopim.com/#visualization/state">dashboard</a>.
     */
    STARTED,
    /**
     * Chat has disconnected the live connection and is waiting for push notifications.
     */
    DISCONNECTED,
    /**
     * Ending chat is in progress but it's depending on the widget connection state.
     */
    ENDING,
    /**
     * Chat has ended.
     */
    ENDED,
    UNKNOWN
}
