package com.zopim.android.sdk.api;

/**
 * Represents an error response from an API call.
 * <br>
 * This interface is used to wrap various framework error responses, such as RetrofitError. The most commonly used
 * methods are:
 * <p/>
 * <ul>
 * <li>{@link #getReason()}</li>
 * <li>{@link #getStatus()}</li>
 * </ul>
 */
interface ErrorResponse {

    /**
     * Definition of kind of an error that occurred
     * <ul>
     * <li>{@link Kind#HTTP} A non-200 HTTP status code was received from the server.</li>
     * <li>{@link Kind#NETWORK} An {@link java.io.IOException} occurred while communicating to the server.</li>
     * <li>{@link Kind#UNEXPECTED} An internal error occurred while attempting to execute a request.</li>
     * </ul>
     */
    enum Kind {

        HTTP, NETWORK, UNEXPECTED
    }
}
