package com.zopim.android.sdk.api;

import android.annotation.SuppressLint;
import android.content.Context;
import android.support.annotation.NonNull;
import android.support.annotation.Nullable;
import android.support.v4.app.FragmentActivity;
import com.zendesk.logger.Logger;
import com.zendesk.util.StringUtils;
import com.zopim.android.sdk.breadcrumbs.Event;
import com.zopim.android.sdk.breadcrumbs.Events;
import com.zopim.android.sdk.data.DataSource;
import com.zopim.android.sdk.data.PathDataSource;
import com.zopim.android.sdk.model.PushData;
import com.zopim.android.sdk.model.VisitorInfo;
import com.zopim.android.sdk.store.Storage;
import com.zopim.android.sdk.util.AppInfo;
import java.util.Locale;

/**
 * Definition for initialization and configuration of the chat.
 * <p>
 * Firstly, to initialize the chat call {@link ZopimChatApi#init(String)} with the correct account key obtained at
 * your Zopim account configuration page.
 * </p>
 * <p>
 * A global chat configuration can be provided at initialization which will apply to all chat sessions that get started.
 * Additionally, each chat session can be configured separately during chat start
 * {@link ZopimChatApi#start(android.support.v4.app.FragmentActivity)}.
 * Starting a chat will provide an instance of {@link ChatApi} used for chat communication. That chat is the bound to
 * the lifecycle of the activity that was used to start the chat.
 * </p>
 *
 * @see <a href="https://dashboard.zopim.com/#widget/getting_started">Getting Started</a>
 * @see ChatApi
 */
public abstract class ZopimChatApi implements ChatApi, ChatSession {

    /**
     * Initiates chat and returns {@link ZopimChatApi.DefaultConfig} configuration builder to be used for configuring
     * the global chat settings.
     * This configuration will apply to all new instances of a chat session unless a new session configuration is
     * provided when starting the new chat.
     *
     * @param accountKey Your account key obtained from the Zopim widget config page. Will configure chat to use your
     *                   Zopim instance.
     * @return configuration builder for setting the global chat configuration
     */
    public static DefaultConfig init(String accountKey) {
        // This code was redacted by Java Censor - Learn more about it at https://github.com/schlan/java-censor
        throw new java.lang.RuntimeException("Source removed");
    }

    /**
     * Starts the chat with {@link com.zopim.android.sdk.api.ZopimChatApi.DefaultConfig} global configuration. Chat
     * needs to be previously initialized.
     *
     * @param activity that holds the chat session
     * @return chat session instance
     */
    public static synchronized ChatApi start(FragmentActivity activity) {
        // This code was redacted by Java Censor - Learn more about it at https://github.com/schlan/java-censor
        throw new java.lang.RuntimeException("Source removed");
    }

    /**
     * Attempts to resume the existing chat if possible. Chat needs to be previously initialized.
     * <p>
     * Resuming a chat will be possible if the previous chat was not ended via {@link ZopimChatApi#endChat()} or
     * expired.
     * Chat timeout time, defined here {@link ChatSession#DEFAULT_CHAT_SESSION_TIMEOUT} is the time that expired
     * after the last message exchange.
     * If resuming was successful it will restore chat configuration from the server. If chat can not be resumed this
     * will still return the chat instance but it won't be able to chat because it has ended
     * {@link ZopimChatApi#hasEnded()}.
     * </p>
     * <p>
     * Resumed chat might not be immediately ready to communicate.
     * </p>
     *
     * @param activity that holds the chat session
     * @return chat session instance
     */
    public static synchronized ChatApi resume(@SuppressWarnings("unused") FragmentActivity activity) {
        // This code was redacted by Java Censor - Learn more about it at https://github.com/schlan/java-censor
        throw new java.lang.RuntimeException("Source removed");
    }

    /**
     * Gets chat data source defined in
     * {@link com.zopim.android.sdk.data.DataSource} and {@link com.zopim.android.sdk.data.PathDataSource}
     * <p>
     * Data source provides subscription to data update broadcasts. It also enables to get current state of a data path.
     * </p>
     *
     * @return data source
     */
    @NonNull
    public static DataSource getDataSource() {
        // This code was redacted by Java Censor - Learn more about it at https://github.com/schlan/java-censor
        throw new java.lang.RuntimeException("Source removed");
    }

    /**
     * Configures the global {@link com.zopim.android.sdk.model.VisitorInfo}
     * <p>
     * Visitor info can be set at any point, but the changes will take effect at next chat session start
     * </p>
     *
     * @param visitorInfo visitor data from {@link com.zopim.android.sdk.model.VisitorInfo}
     */
    public static void setVisitorInfo(VisitorInfo visitorInfo) {
        // This code was redacted by Java Censor - Learn more about it at https://github.com/schlan/java-censor
        throw new java.lang.RuntimeException("Source removed");
    }

    /**
     * Leaves an event trace.
     * <p>
     * It is possible to track event prior chat session being started.
     * Tracked events will be sent as soon as chat session is connected and any further event after that point will
     * be sent immediately.
     * </p>
     *
     * @param description of the event
     */
    public static void trackEvent(String description) {
        // This code was redacted by Java Censor - Learn more about it at https://github.com/schlan/java-censor
        throw new java.lang.RuntimeException("Source removed");
    }

    /**
     * Set the push token to allow agent message to be sent to the app via push notifications.
     *
     * @param token the token received from FCM
     */
    public static void setPushToken(final String token) {
        // This code was redacted by Java Censor - Learn more about it at https://github.com/schlan/java-censor
        throw new java.lang.RuntimeException("Source removed");
    }

    /**
     * Clear the token so that push notifications are no longer sent for agent chat messages.
     */
    public static void clearPushToken() {
        // This code was redacted by Java Censor - Learn more about it at https://github.com/schlan/java-censor
        throw new java.lang.RuntimeException("Source removed");
    }

    /**
     * Get the push token
     */
    @Nullable
    public static String getPushToken() {
        // This code was redacted by Java Censor - Learn more about it at https://github.com/schlan/java-censor
        throw new java.lang.RuntimeException("Source removed");
    }

    /**
     * Notify the SDK of FCM message receipt.
     *
     * @param pushData the push notification data
     */
    public static void onMessageReceived(@NonNull final PushData pushData) {
        // This code was redacted by Java Censor - Learn more about it at https://github.com/schlan/java-censor
        throw new java.lang.RuntimeException("Source removed");
    }

    /**
     * Gets reconnect timeout that was configured via {@link ZopimChatApi.DefaultConfig#reconnectTimeout}
     * If timeout was not configured it will return the {@link ChatSession#DEFAULT_RECONNECT_TIMEOUT}
     *
     * @return reconnect timeout
     */
    @NonNull
    public static Long getReconnectTimeout() {
        // This code was redacted by Java Censor - Learn more about it at https://github.com/schlan/java-censor
        throw new java.lang.RuntimeException("Source removed");
    }

    /**
     * Gets initialization timeout that was configured via {@link ZopimChatApi.DefaultConfig#initializationTimeout}
     * If timeout was not configured it will return the {@link ChatSession#DEFAULT_CHAT_INITIALIZATION_TIMEOUT}
     *
     * @return initialization timeout
     */
    @NonNull
    public static Long getInitializationTimeout() {
        // This code was redacted by Java Censor - Learn more about it at https://github.com/schlan/java-censor
        throw new java.lang.RuntimeException("Source removed");
    }

    /**
     * Configuration class for global chat configuration
     * <p>
     * Configuration specified here will be applicable to all chat sessions that get started. This configuration can
     * be overridden by a {@link com.zopim.android.sdk.api.ZopimChatApi.SessionConfig} configuration provided when
     * starting a new chat.
     * </p>
     *
     * @see com.zopim.android.sdk.api.ZopimChatApi.SessionConfig
     */
    public static class DefaultConfig<T extends DefaultConfig> extends ApiConfigBuilder<T> {

        /**
         * Disables {@link com.zopim.android.sdk.store.VisitorInfoPrefsStorage} storage.
         * Configured {@link com.zopim.android.sdk.model.VisitorInfo} will not be stored for later reuse.
         *
         * @return configuration builder
         */
        @NonNull
        public DefaultConfig disableVisitorInfoStorage() {
            // This code was redacted by Java Censor - Learn more about it at https://github.com/schlan/java-censor
            throw new java.lang.RuntimeException("Source removed");
        }

        /**
         * Sets chat initialization timeout.
         * If chat fails to initialize in this time it will broadcast an intent with action
         * {@link ChatSession#ACTION_CHAT_INITIALIZATION_TIMEOUT}
         *
         * @param milliseconds after which chat initialization should timeout
         * @return configuration builder
         */
        @NonNull
        public DefaultConfig initializationTimeout(long milliseconds) {
            // This code was redacted by Java Censor - Learn more about it at https://github.com/schlan/java-censor
            throw new java.lang.RuntimeException("Source removed");
        }

        /**
         * Sets the reconnect timeout.
         * This configures the connection retry timeout used in the UI
         *
         * @param milliseconds after which chat reconnect should timeout
         * @return configuration builder
         */
        @NonNull
        public DefaultConfig reconnectTimeout(long milliseconds) {
            // This code was redacted by Java Censor - Learn more about it at https://github.com/schlan/java-censor
            throw new java.lang.RuntimeException("Source removed");
        }

        /**
         * Sets chat session timeout.
         * This configures the time after which the chat will timeout and disconnect if no further visitor message
         * has been sent.
         *
         * @param milliseconds after which chat session should timeout
         * @return configuration builder
         */
        @NonNull
        public DefaultConfig sessionTimeout(long milliseconds) {
            // This code was redacted by Java Censor - Learn more about it at https://github.com/schlan/java-censor
            throw new java.lang.RuntimeException("Source removed");
        }

        /**
         * Saves the global chat configuration that will be available to all chat sessions.
         *
         * @deprecated As of release 1.2, calling build is not required.
         */
        @Deprecated
        public Void build() {
            // This code was redacted by Java Censor - Learn more about it at https://github.com/schlan/java-censor
            throw new java.lang.RuntimeException("Source removed");
        }
    }

    /**
     * Configuration class for session chat configuration
     * <p>
     * Prepares new chat session config. Provided configuration will apply only to this session.
     * Once configured call build() to return a {@link ZopimChatApi} instance to use.
     * </p>
     */
    public static class SessionConfig<T extends SessionConfig> extends ApiConfigBuilder<T> {

        @NonNull
        @Override
        public T department(String department) {
            // This code was redacted by Java Censor - Learn more about it at https://github.com/schlan/java-censor
            throw new java.lang.RuntimeException("Source removed");
        }

        @NonNull
        @Override
        public T tags(String... tags) {
            // This code was redacted by Java Censor - Learn more about it at https://github.com/schlan/java-censor
            throw new java.lang.RuntimeException("Source removed");
        }

        @NonNull
        @Override
        public T visitorPathOne(String visitorPath) {
            // This code was redacted by Java Censor - Learn more about it at https://github.com/schlan/java-censor
            throw new java.lang.RuntimeException("Source removed");
        }

        @NonNull
        @Override
        public T visitorPathTwo(String visitorPath) {
            // This code was redacted by Java Censor - Learn more about it at https://github.com/schlan/java-censor
            throw new java.lang.RuntimeException("Source removed");
        }

        @NonNull
        public ChatApi build(@NonNull FragmentActivity fragmentActivity) {
            // This code was redacted by Java Censor - Learn more about it at https://github.com/schlan/java-censor
            throw new java.lang.RuntimeException("Source removed");
        }
    }
}
