package com.zopim.android.sdk.attachment;

import com.zendesk.util.FileUtils;
import com.zendesk.util.StringUtils;
import java.io.File;

/**
 * Definition of a file extensions used in Zopim attachment upload and download events.
 * Extensions as defined in {@link android.webkit.MimeTypeMap}
 * <ul>
 * <li>{@link FileExtension#JPG} image type</li>
 * <li>{@link FileExtension#JPEG} image type</li>
 * <li>{@link FileExtension#PNG} image type</li>
 * <li>{@link FileExtension#GIF} image type</li>
 * <li>{@link FileExtension#PDF} document type</li>
 * <li>{@link FileExtension#TXT} text type</li>
 * <li>{@link FileExtension#UNKNOWN} unknown type</li>
 * </ul>
 *
 * @see <a href="https://zopim.zendesk.com/entries/23268514-Sending-and-receiving-files-on-Zopim">Zopim attachments page</a>
 */
public enum FileExtension {

    JPG("jpg"),
    JPEG("jpeg"),
    PNG("png"),
    GIF("gif"),
    PDF("pdf"),
    TXT("txt"),
    UNKNOWN("unknown");

    FileExtension(String extension) {
        this.extension = extension;
    }

    /**
     * Gets the value of this raw extension enum
     *
     * @return extension value as defined in the enum
     */
    public String getValue() {
        // This code was redacted by Java Censor - Learn more about it at https://github.com/schlan/java-censor
        throw new java.lang.RuntimeException("Source removed");
    }

    /**
     * Gets extension type that matched the criteria
     * <p>
     * Accepts extension values not containing the dot('.') as defined in {@link android.webkit.MimeTypeMap}.
     * It's case insensitive so both JPG and jpg are valid extensions. See list of valid extensions in {@link FileExtension}.
     * </p>
     *
     * @param extension A file extension without the leading '.'
     * @return extension type or {@link FileExtension#UNKNOWN} if not found
     */
    public static FileExtension valueOfExtension(String extension) {
        // This code was redacted by Java Censor - Learn more about it at https://github.com/schlan/java-censor
        throw new java.lang.RuntimeException("Source removed");
    }

    /**
     * Gets the file extension of the file passed as parameter
     *
     * @param file to interpret
     * @return file extension or {@link FileExtension#UNKNOWN} if not found
     */
    public static FileExtension getExtension(File file) {
        // This code was redacted by Java Censor - Learn more about it at https://github.com/schlan/java-censor
        throw new java.lang.RuntimeException("Source removed");
    }
}
