package com.zopim.android.sdk.model;

import android.support.annotation.NonNull;
import android.support.annotation.Nullable;
import com.google.gson.annotations.Expose;
import com.google.gson.annotations.SerializedName;

/**
 * This is a model class for Department that will be created by {@link com.zopim.android.sdk.data.LivechatDepartmentsPath}.
 * <p>
 * It is used to tell available departments for in a chat session. Configuration of available departments can be done on the agent's dashboard.
 * </p>
 * <p>
 * You can subscribe to department broadcast via {@link com.zopim.android.sdk.data.DataSource#addDepartmentsObserver(java.util.Observer)} using {@link com.zopim.android.sdk.data.observers.DepartmentsObserver}
 * </p>
 * <p>
 * This class is a model that will be serialised to JSON and deserialised from JSON to this
 * model. As such it does not follow the m naming prefix for fields.
 * </p>
 *
 * @see <a href="https://dashboard.zopim.com/#departments">Agent Dashboard</a>
 */
public class Department {

    /**
     * Gets name of the department
     *
     * @return department name
     */
    @Nullable
    public String getName() {
        // This code was redacted by Java Censor - Learn more about it at https://github.com/schlan/java-censor
        throw new java.lang.RuntimeException("Source removed");
    }

    /**
     * Gets availability status of the department
     *
     * @return department status
     */
    @Nullable
    public Status getStatus() {
        // This code was redacted by Java Censor - Learn more about it at https://github.com/schlan/java-censor
        throw new java.lang.RuntimeException("Source removed");
    }

    @Override
    public String toString() {
        // This code was redacted by Java Censor - Learn more about it at https://github.com/schlan/java-censor
        throw new java.lang.RuntimeException("Source removed");
    }

    /**
     * Status of the department
     * <ul>
     *  <li> {@link Status#ONLINE}
     *  <li> {@link Status#OFFLINE}
     *  <li> {@link Status#UNKNOWN}
     * </ul>
     */
    public enum Status {

        /**
         * Department is online
         */
        ONLINE("online"),
        /**
         * Department is offline
         */
        OFFLINE("offline"),
        /**
         * Department is away
         */
        AWAY("away"),
        UNKNOWN("unknown");

        Status(String status) {
            this.status = status;
        }

        /**
         * Gets the value of this status enum
         *
         * @return status name as defined in Zopim protocol
         */
        public String getValue() {
            // This code was redacted by Java Censor - Learn more about it at https://github.com/schlan/java-censor
            throw new java.lang.RuntimeException("Source removed");
        }

        /**
         * Gets the status enum of the value passed as parameter
         *
         * @param value to interpret
         * @return status or {@link com.zopim.android.sdk.model.Department.Status#UNKNOWN} if not found
         */
        @NonNull
        public static Status getStatus(String value) {
            // This code was redacted by Java Censor - Learn more about it at https://github.com/schlan/java-censor
            throw new java.lang.RuntimeException("Source removed");
        }
    }
}
