package com.zopim.android.sdk.model;

import android.support.annotation.Nullable;
import com.google.gson.annotations.Expose;
import com.google.gson.annotations.SerializedName;
import com.zopim.android.sdk.api.ZopimChatApi;

/**
 * This is a model class for user profile information that will be created by {@link com.zopim.android.sdk.data.LivechatProfilePath}.
 * <p>
 * It holds information about the visitor and the chat session this visitor is in.
 * Visitor information if defined here {@link com.zopim.android.sdk.model.VisitorInfo}.
 * Visitor session information is used by the SDK only for reconnect purposes.
 * </p>
 * <p>
 * You can subscribe to profile broadcast via {@link com.zopim.android.sdk.data.DataSource#addProfileObserver(java.util.Observer)} using {@link com.zopim.android.sdk.data.observers.ProfileObserver}
 * </p>
 * <p>
 * This class is a model that will be serialised to JSON and deserialised from JSON to this
 * model. As such it does not follow the m naming prefix for fields.
 * </p>
 *
 * @see ZopimChatApi#setVisitorInfo(VisitorInfo)
 */
public class Profile {

    /**
     * Gets machine id of the current chat session.
     * <p>
     * It can be used to reconnect to the that chat session.
     * </p>
     *
     * @return machine id of the chat session
     */
    @Nullable
    public String getMachineId() {
        // This code was redacted by Java Censor - Learn more about it at https://github.com/schlan/java-censor
        throw new java.lang.RuntimeException("Source removed");
    }

    /**
     * Gets email configured of the visitor in the chat session
     *
     * @return email address
     */
    @Nullable
    public String getEmail() {
        // This code was redacted by Java Censor - Learn more about it at https://github.com/schlan/java-censor
        throw new java.lang.RuntimeException("Source removed");
    }

    /**
     * Gets display name of the visitor in the chat session
     *
     * @return display name of the visitor
     */
    @Nullable
    public String getDisplayName() {
        // This code was redacted by Java Censor - Learn more about it at https://github.com/schlan/java-censor
        throw new java.lang.RuntimeException("Source removed");
    }

    /**
     * Gets phone number of the visitor in the chat session
     *
     * @return phone number of the visitor
     */
    @Nullable
    public String getPhoneNumber() {
        // This code was redacted by Java Censor - Learn more about it at https://github.com/schlan/java-censor
        throw new java.lang.RuntimeException("Source removed");
    }

    /**
     * Gets department id of the department that this visitor is assigned to.
     * <p>
     * Departments are defined in {@link com.zopim.android.sdk.data.LivechatDepartmentsPath}
     * </p>
     *
     * @return id of the department
     */
    @Nullable
    public String getDepartmentId() {
        // This code was redacted by Java Censor - Learn more about it at https://github.com/schlan/java-censor
        throw new java.lang.RuntimeException("Source removed");
    }

    @Override
    public String toString() {
        // This code was redacted by Java Censor - Learn more about it at https://github.com/schlan/java-censor
        throw new java.lang.RuntimeException("Source removed");
    }
}
